" Vim syntax file
" Language   : BogusForth v. 0.9.4
" Maintainer : Antonio Maschio <tbin@libero.it>
" Last change: 2004 october

" Thanks to...
" Christian V. J. Brssow <cvjb@epost.de> for the forth.vim

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
	syntax clear
elseif exists("b:current_syntax")
	finish
endif

" Synchronization method
syn sync ccomment maxlines=200

" Characters allowed in keywords
if version >= 600
	setlocal iskeyword=!,@,33-64,A-Z,91-96,a-z,123-126,128-255
else
	set iskeyword=!,@,33-64,A-Z,91-96,a-z,123-126,128-255
endif

" Matchin case
syn case match

"Floating point number, with do
syn match	bfNumber		"\d\+\.\d*"

" Keywords
syn keyword	bfTODO		contained TODO FIXME XXX

" bfCommentGroup allows adding matches for special things in comments
" taken from c.vim by B. Moolenar
syn cluster	bfCommentGroup	contains=bfTODO
 
" cycling
syn match bfRepeat 	/#/
syn match bfLoop 	   /d/
syn match bfLeave    /h/

" math, logical and bitwise operators and functions
syn match bfOpa 		/a/
syn match bfOpo 		/o/
syn match bfOpn 		/n/
syn match bfOpx 		/x/
syn match bfOpplus  	/+/
syn match bfOptimes 	/*/
syn match bfOpminus 	/-/
syn match bfOpdiv   	/\\/
syn match bfOpneg   	/\//
syn match bfOppow   	/\^/
syn match bfOproot  	/!/
syn match bfOpequal 	/=/
syn match bfOpgt    	/>/
syn match bfOpand   	/&/
syn match bfOpor    	/|/
syn match bfOpnot   	/\~/
syn match bfOpln     /l/
syn match bfOpmod   	/m/
syn match bfOpran   	/g/
syn match bfOpsin    /s/
syn match bfOpcos    /c/
syn match bfOpatan   /t/
syn match bfOpid     /v/
syn match bfOpTok    /w/
														 
" stack manipulation
syn match bfStdup  	/%/
syn match bfStdrop 	/;/
syn match bfStswap 	/\$/
syn match bfStrot  	/_/
syn match bfStroll 	/r/
syn match bfStpick 	/p/
syn match bfStstck 	/:/
syn match bfStempt 	/e/
syn match bfStdpth 	/}/

" if-then-else and tear away
syn match bfIfif 		/?/

" functions
syn region bfFunction start=/\[/ end=/\]/ end=/$/ contains=ALLBUT,bfSyBr
"syn match bfFuncStart /\[/ skipwhite
"syn match bfFuncEnd   /\]/ contained

" input/output
syn match bfIOi /i/
syn match bfIOj /j/
syn match bfIOk /k/
syn match bfIOl /</
syn match bfIOop /(/
syn match bfIOcp /)/
syn match bfIObr /]/
syn match bfIOdot /\./
syn match bfIOy /y/
syn match bfIOb /b/
syn match bfIOf /f/

" system commands
syn match bfSysquit /q/
syn keyword bfSys bye cd def debug dir edit exit halt help ls now pwd quit  
syn keyword bfSys ref reset savedef savevar savesys sh show status undef 
syn keyword bfSys version voc words where quiet exitwarn clearonerror errorshow
syn keyword bfSys precision stoponerror view
syn region bfSys start=/def/ end=/$/

" storing/fetching
syn match bfStore /\a!/
syn match bfFetch /\a:/

" string/char 
syn match bfStr1 /'/
syn match bfStr2 /`./
syn match bfStr3 /,/
syn match bfStru /u/

" Strings
syn region bfString start=/"/ skip=/\\"/ end=/"/ end=/$/

" Varia
syn match bfVar1 /\~t/ 
syn match bfVar2 /\~d/
syn match bfVar3 /\~>/
syn match bfVar4 /\~</
syn match bfVar5 /\~:/

" Comments
syn region bfComment start=/{/ end=/}/ end=/$/ contains=@bfCommentGroup
syn region bfComment start=/^#/ end=/$/
syn match  bfCapComm /\<\u\+\>/

" function command
syn match bfFunctionC0 /\a:@/
syn match bfFunctionC1 /\a@/
syn match bfFunctionC2 /\]@/


" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_bf_syn_inits")
	if version < 508
		let did_bf_syn_inits = 1
		command -nargs=+ HiLink hi link <args>
	else
		command -nargs=+ HiLink hi def link <args>
	endif

	" The default methods for highlighting. Can be overriden later.

" math, logical and bitwise operators
	HiLink bfOpa 	  Special
	HiLink bfOpo 	  Special
	HiLink bfOpn 	  Special
	HiLink bfOpx 	  Special
	HiLink bfOpplus  Special
	HiLink bfOptimes Special
	HiLink bfOpminus Special
	HiLink bfOpdiv   Special
	HiLink bfOpneg   Special
	HiLink bfOppow   Special
	HiLink bfOproot  Special
	HiLink bfOpequal Special
	HiLink bfOpgt    Special
	HiLink bfOpand   Special
	HiLink bfOpor    Special  
	HiLink bfOpnot   Special  
	HiLink bfOpln    Special
	HiLink bfOpmod   Special
	HiLink bfOpran   Special
	HiLink bfOpsin   Special
	HiLink bfOpcos   Special
	HiLink bfOpatan  Special
	HiLink bfOpid    Special
	HiLink bfOpTok   Special
	HiLink bfVar1	  Type
	HiLink bfVar2	  Type
	HiLink bfVar3	  Type
	HiLink bfVar4	  Type
	HiLink bfVar5	  Type
														 
" stack manipulation
	HiLink bfStdup  PreProc
	HiLink bfStdrop PreProc
	HiLink bfStswap PreProc
	HiLink bfStrot  PreProc
	HiLink bfStroll PreProc
	HiLink bfStpick PreProc
	HiLink bfStstck PreProc
	HiLink bfStempt PreProc
	HiLink bfStdpth PreProc

" if-then-else and tear away
	HiLink bfIfif Conditional
	HiLink bfIftr Conditional

" cycling
	HiLink bfRepeat Repeat
	HiLink bfLoop   Repeat
	HiLink bfLeave  Repeat
	HiLink bfIndex  Repeat

" functions
	HiLink bfFunctionC0 Function 
	HiLink bfFunctionC1 Function 
	HiLink bfFunctionC2 Function 

" input/output
	HiLink bfIOi Comment
	HiLink bfIOj Comment
	HiLink bfIOk Comment
	HiLink bfIOl Comment
	HiLink bfIOop Comment
	HiLink bfIOcp Comment
	HiLink bfIOdot Comment
	HiLink bfIObr Comment
	HiLink bfIOy Comment
	HiLink bfIOb Comment
	HiLink bfIOf Comment

" system commands
	HiLink bfSysquit Type
	HiLink bfSys Type

" storing/fetching
	HiLink bfStore Type
	HiLink bfFetch Type

" string/char 
	HiLink bfStr1 String
	HiLink bfStr2 String
	HiLink bfStr3 String
	HiLink bfStru String
	HiLink bfComment Function
	HiLink bfCapComm Function
	HiLink bfString String
	HiLink bfFunction Function
	HiLink bfTODO Todo
"	HiLink bfFuncStart Function
"	HiLink bfFuncEnd Function

	delcommand HiLink
endif

let b:current_syntax = "bf"

" vim:ts=3:sw=3
